@@ -25,11 +25,11 @@ LASTFM_APIKEY = "1e1d53528c86406757a6887addef0ace"
 BASE_LASTFM = "http://ws.audioscrobbler.com/2.0/?method=album.getinfo"
 
 
-BASE_MSN = "http://www.bing.com/images/search?q="
-MSN_MEDIUM = "+filterui:imagesize-medium"
-MSN_SMALL = "+filterui:imagesize-medium"
-MSN_SQUARE = "+filterui:aspect-square"
-MSN_PHOTO = "+filterui:photo-graphics"
+BASE_GOOGLE = "https://www.google.com/search?tbm=isch&q="
+GOOGLE_MEDIUM = "&tbs=isz:m"
+GOOGLE_SMALL = "&tbs=isz:s"
+GOOGLE_SQUARE = "&iar:s"
+GOOGLE_PHOTO = "&itp:photo"
 
 CACHE_LOCATION = os.path.join (os.getenv ("HOME"), ".cache", "mussorgsky")
 # LastFM:
@@ -85,8 +85,8 @@ class MussorgskyAlbumArt:
             print "Album art already there " + filename
             album_art_available = True
         else:
-            results_page = self.__msn_images (artist, album)
-            for online_resource in self.__get_url_from_msn_results_page (results_page):
+            results_page = self.__google_images (artist, album)
+            for online_resource in self.__get_url_from_google_results_page (results_page):
                 print "Choosed:", online_resource
                 content = self.urllib_wrapper.get_url (online_resource)
                 if (content):
@@ -113,19 +113,20 @@ class MussorgskyAlbumArt:
         """
         return a list of paths of possible album arts
         """
-        results_page = self.__msn_images (artist, album)
+        results_page = self.__google_images (artist, album)
         return self.__process_results_page (results_page, max_alternatives)
 
     def get_alternatives_free_text (self, search_text, max_alternatives=4):
-        results_page = self.__msn_images_free_text (search_text)
+        results_page = self.__google_images_free_text (search_text)
         return self.__process_results_page (results_page, max_alternatives)
 
     def __process_results_page (self, results_page, max_alternatives):
         counter = 0
         threads = []
-        for image_url in self.__get_url_from_msn_results_page (results_page):
+        for image_url in self.__get_url_from_google_results_page (results_page):
             if (not image_url):
                 # Some searches doesn't return anything at all!
+                print "No images result returned"
                 break
 
             if (counter >= max_alternatives):
@@ -164,13 +165,13 @@ class MussorgskyAlbumArt:
             if os.path.exists (filepath):
                 os.remove (filepath)
 
-    def __msn_images (self, artist, album):
+    def __google_images (self, artist, album):
 
         good_artist = self.__clean_string_for_search (artist)
         good_album = self.__clean_string_for_search (album)
         
         if (good_album and good_artist):
-            full_try = BASE_MSN + good_album + "+" + good_artist + MSN_MEDIUM + MSN_SQUARE
+            full_try = BASE_GOOGLE + good_album + "+" + good_artist + GOOGLE_MEDIUM + GOOGLE_SQUARE
             print "Searching (album + artist): %s" % (full_try)
             result = self.urllib_wrapper.get_url (full_try)
             if (result and result.find ("no_results") == -1):
@@ -181,14 +182,14 @@ class MussorgskyAlbumArt:
                 print "Ignoring '%s': too generic" % (album)
                 pass
             else:
-                album_try = BASE_MSN + good_album + MSN_MEDIUM + MSN_SQUARE
+                album_try = BASE_GOOGLE + good_album + GOOGLE_MEDIUM + GOOGLE_SQUARE
                 print "Searching (album): %s" % (album_try)
                 result = self.urllib_wrapper.get_url (album_try)
                 if (result and result.find ("no_results") == -1):
                     return result
             
         if (artist):
-            artist_try = BASE_MSN + good_artist + "+CD+music"  + MSN_SMALL + MSN_SQUARE + MSN_PHOTO
+            artist_try = BASE_GOOGLE + good_artist + "+CD+music"  + GOOGLE_SMALL + GOOGLE_SQUARE + GOOGLE_PHOTO
             print "Searching (artist CD): %s" % (artist_try)
             result = self.urllib_wrapper.get_url (artist_try)
             if (result and result.find ("no_results") == -1):
@@ -196,13 +197,13 @@ class MussorgskyAlbumArt:
         
         return None
 
-    def __msn_images_free_text (self, search_text):
-        full_try = BASE_MSN + self.__clean_string_for_search (search_text) + MSN_MEDIUM + MSN_SQUARE
+    def __google_images_free_text (self, search_text):
+        full_try = BASE_GOOGLE + self.__clean_string_for_search (search_text) + GOOGLE_MEDIUM + GOOGLE_SQUARE
         result = self.urllib_wrapper.get_url (full_try)
         return result
     
 
-    def __get_url_from_msn_results_page (self, page):
+    def __get_url_from_google_results_page (self, page):
         if (not page):
             return
 
@@ -212,16 +213,18 @@ class MussorgskyAlbumArt:
         # 500 is just a safe limit
         for i in range (0, 500):
             # Iterate until find a jpeg
-            start = page.find ("imgurl:&quot;", starting_at)
+            start = page.find ("imgurl=", starting_at)
             if (start == -1):
+                print "Can't find URL in results"
                 yield None
-            end = page.find ("&", start + len ("imgurl:&quot;"))
-            current_option = page [start + len ("imgurl:&quot;"): end].replace ("amp;", "")
+            end = page.find ("&", start + len ("imgurl="))
+            current_option = page [start + len ("imgurl="): end].replace ("amp;", "")
             if (current_option.lower().endswith (".jpg") or
                 current_option.lower().endswith (".jpeg")):
                 yield current_option
             starting_at = end
         
+        
 
     def __clean_string_for_search (self, text):
         if (not text or len (text) < 1):
